{% load i18n %}
<div id="feedback-submit-error">
    <div class="feedback-logo">{% trans 'Feedback' %}</div>
    <p>{% trans 'Sadly an error occurred while sending your feedback. Please try again.' %}</p>
    <button class="feedback-close-btn feedback-btn-blue">{% trans 'OK' %}</button>
    <div class="feedback-wizard-close"></div>
</div>