{% load i18n %}
<div id="feedback-submit-success">
    <div class="feedback-logo">{% trans 'Feedback' %}</div>
    <p>{% trans 'Thank you for your feedback. We value every piece of feedback we receive.'%}</p>
    <p>{% trans 'We cannot respond individually to every one, but we will use your comments as we strive to improve your experience.' %}</p>
    <button class="feedback-close-btn feedback-btn-blue">{% trans 'OK' %}</button>
    <div class="feedback-wizard-close"></div>
</div>