{% load i18n %}
<div id="feedback-welcome">
    <div class="feedback-logo">{% trans 'Feedback' %}</div>
    <p>{% trans 'Feedback lets you send us suggestions about our products. We welcome problem reports, feature ideas and general comments.' %}</p>
    <p>{% trans 'Start by writing a brief description:' %}</p><textarea id="feedback-note-tmp"></textarea>
    <p>{% trans "Next we'll let you identify areas of the page related to your description." %}</p>
    <button id="feedback-welcome-next" class="feedback-next-btn feedback-btn-gray">{% trans 'Next' %}</button>
    <div id="feedback-welcome-error">{% trans 'Please enter a description.' %}</div>
    <div class="feedback-wizard-close"></div>
</div>